 # Getting started

The following documents will give you an overview of how to install and use
napari. For more detailed use-cases, check out the [napari tutorials](./index)
or [How-to guides](../howtos/index).

- [napari quick start](./fundamentals/quick_start): This tutorial is for napari
first-timers, to give them a quick glance of what napari does, and give it a try
right away.
- [How to install napari on your machine](./fundamentals/installation): This
guide will teach you how to do a clean install of napari and launch the viewer.
- [Getting started with napari](./fundamentals/getting_started): This tutorial
will teach you all the different ways to launch napari.
- [napari viewer tutorial](./fundamentals/viewer): This tutorial will teach you
about the napari viewer, including how to use its graphical user interface (GUI)
and how the data within it is organized.
- [Layers at a glance](../guides/layers): An overview of the napari *Layers*,
the basic viewable objects that can be added to a viewer.